@@ -41,7 +41,7 @@ readOne h = do
 		Right True  -> B.hGetNonBlocking h 4096
 		Right False -> return B.empty
 
-tlsclient :: Handle -> TLSCtx -> IO ()
+tlsclient :: Handle -> TLSCtx Handle -> IO ()
 tlsclient srchandle dsthandle = do
 	hSetBuffering srchandle NoBuffering
 
@@ -76,7 +76,7 @@ tlsserver srchandle dsthandle = do
 		d <- recvData srchandle
 		putStrLn ("received: " ++ show d)
 		sendData srchandle (L.pack $ map (toEnum . fromEnum) "this is some data")
-		hFlush (ctxHandle srchandle)
+		hFlush (ctxConnection srchandle)
 		return False
 	putStrLn "end"
 
@@ -88,7 +88,7 @@ clientProcess certs handle dsthandle dbg _ = do
 		}
 
 	let serverstate = defaultParams
-		{ pAllowedVersions = [SSL3,TLS10,TLS11]
+		{ pAllowedVersions = [SSL3,TLS10,TLS11,TLS12]
 		, pCiphers         = ciphers
 		, pCertificates    = certs
 		, pWantClientCert  = False
@@ -229,7 +229,7 @@ doClient pargs = do
 	let crecv = if validCert pargs then certificateVerifyChain else (\_ -> return CertificateUsageAccept)
 	let clientstate = defaultParams
 		{ pConnectVersion = TLS10
-		, pAllowedVersions = [ TLS10, TLS11 ]
+		, pAllowedVersions = [TLS10,TLS11,TLS12]
 		, pCiphers = ciphers
 		, pCertificates = []
 		, pLogging = logging
